@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Chromatic and diatonic musical ornamentation
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0201';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -155,24 +155,21 @@ sub trill {
 
 
 sub mordent {
-    my ($self, $duration, $pitch, $direction) = @_;
+    my ($self, $duration, $pitch, $offset) = @_;
 
-    $direction ||= 1;
+    $offset ||= 1;
 
-    my ($above, $below);
+    my $alt;
 
     if ($self->scale_name eq 'chromatic') {
-        $above = Music::Note->new($pitch, 'ISO')->format('midinum') + 1;
-        $above = Music::Note->new($above, 'midinum')->format('ISO');
-        $below = Music::Note->new($pitch, 'ISO')->format('midinum') - 1;
-        $below = Music::Note->new($below, 'midinum')->format('ISO');
+        $alt = Music::Note->new($pitch, 'ISO')->format('midinum') + $offset;
+        $alt = Music::Note->new($alt, 'midinum')->format('ISO');
     }
     else {
         my $i = first_index { $_ eq $pitch } @{ $self->_scale };
-        $above = $self->_scale->[ $i + 1 ];
-        $below = $self->_scale->[ $i - 1 ];
+        $alt = $self->_scale->[ $i + $offset ];
     }
-    print "Above/Below: $above / $below\n" if $self->verbose;
+    print "Alternate note: $alt\n" if $self->verbose;
 
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
     my $z = sprintf '%0.f', $x / 8;
@@ -183,17 +180,7 @@ sub mordent {
 
     my @mordent;
 
-    push @mordent, [$z, $pitch];
-    if ($direction == 1) {
-        push @mordent, [$z, $above];
-    }
-    elsif ($direction == -1) {
-        push @mordent, [$z, $below];
-    }
-    else {
-        croak "Unknown turn direction: $direction";
-    }
-    push @mordent, [$y, $pitch];
+    push @mordent, [$z, $pitch], [$z, $alt], [$y, $pitch];
     print 'Mordent: ', ddc(\@mordent) if $self->verbose;
 
     return \@mordent;
@@ -213,7 +200,7 @@ Music::MelodicDevice::Ornamentation - Chromatic and diatonic musical ornamentati
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSIS
 
@@ -308,6 +295,9 @@ second one given by the B<offset>.
 "A rapid alternation between an indicated note [the B<pitch>], the
 note above or below, and the indicated note again."
 
+An B<offset> of C<1> (the default) returns an upper mordent one pitch
+away.  An B<offset> of C<-1> returns a lower mordent.
+
 So if the B<pitch> is C<D5>, a diatonic upper mordent would be
 C<D5-E5-D5>.  A chromatic lower mordent would be C<D5-C#5-D5>.
 
